@@ -7,6 +7,8 @@ Tests for the 'session' channel implementation in twisted.conch.ssh.session.
 See also RFC 4254.
 """
 
+from __future__ import division, absolute_import
+
 import os, signal, sys, struct
 
 from zope.interface import implementer
@@ -31,11 +33,10 @@ class SubsystemOnlyAvatar(object):
     def lookupSubsystem(self, name, data):
         """
         If the other side requests the 'subsystem' subsystem, allow it by
-        returning a MockProtocol to implement it.  Otherwise, return
-        None which is interpreted by SSHSession as a failure.
+        returning a MockProtocol to implement it. Otherwise raise an assertion.
         """
-        if name == 'subsystem':
-            return MockProtocol()
+        assert name == b'subsystem'
+        return MockProtocol()
 
 
 
@@ -52,7 +53,7 @@ class StubAvatar:
         MockProtocol.  If they request neither, then None is returned which is
         interpreted by SSHSession as a failure.
         """
-        if name == 'TestSubsystem':
+        if name == b'TestSubsystem':
             self.subsystem = MockProtocol()
             self.subsystem.packetData = data
             return self.subsystem
@@ -97,7 +98,7 @@ class StubSessionForStubAvatar(object):
         If the terminal is 'bad', fail.  Otherwise, store the information in
         the ptyRequest variable.
         """
-        if terminal != 'bad':
+        if terminal != b'bad':
             self.ptyRequest = (terminal, window, modes)
         else:
             raise RuntimeError('not getting a pty')
@@ -134,9 +135,9 @@ class StubSessionForStubAvatar(object):
         store the command and raise an error.
         """
         self.execCommandLine = command
-        if command == 'success':
+        if command == b'success':
             self.execProtocol = pp
-        elif command[:6] == 'repeat':
+        elif command[:6] == b'repeat':
             self.execProtocol = pp
             self.execTransport = EchoTransport(pp)
             pp.outReceived(command[7:])
@@ -164,85 +165,6 @@ components.registerAdapter(StubSessionForStubAvatar, StubAvatar,
 
 
 
-
-class MockProcessProtocol(protocol.ProcessProtocol):
-    """
-    A mock ProcessProtocol which echoes back data sent to it and
-    appends a tilde.  The tilde is appended so the tests can verify that
-    we received and processed the data.
-
-    @ivar packetData: C{str} of data to be sent when the connection is made.
-    @ivar data: a C{str} of data received.
-    @ivar err: a C{str} of error data received.
-    @ivar inConnectionOpen: True if the input side is open.
-    @ivar outConnectionOpen: True if the output side is open.
-    @ivar errConnectionOpen: True if the error side is open.
-    @ivar ended: False if the protocol has not ended, a C{Failure} if the
-        process has ended.
-    """
-    packetData = ''
-
-
-    def connectionMade(self):
-        """
-        Set up variables.
-        """
-        self.data = ''
-        self.err = ''
-        self.inConnectionOpen = True
-        self.outConnectionOpen = True
-        self.errConnectionOpen = True
-        self.ended = False
-        if self.packetData:
-            self.outReceived(self.packetData)
-
-
-    def outReceived(self, data):
-        """
-        Data was received.  Store it and echo it back with a tilde.
-        """
-        self.data += data
-        if self.transport is not None:
-            self.transport.write(data + '~')
-
-
-    def errReceived(self, data):
-        """
-        Error data was received.  Store it and echo it back backwards.
-        """
-        self.err += data
-        self.transport.write(data[::-1])
-
-
-    def inConnectionLost(self):
-        """
-        Close the input side.
-        """
-        self.inConnectionOpen = False
-
-
-    def outConnectionLost(self):
-        """
-        Close the output side.
-        """
-        self.outConnectionOpen = False
-
-
-    def errConnectionLost(self):
-        """
-        Close the error side.
-        """
-        self.errConnectionOpen = False
-
-
-    def processEnded(self, reason):
-        """
-        End the process and store the reason.
-        """
-        self.ended = reason
-
-
-
 class EchoTransport:
     """
     A transport for a ProcessProtocol which echos data that is sent to it with
@@ -251,7 +173,7 @@ class EchoTransport:
     C{ProcessProtocol} with a 0 exit code.
 
     @ivar proto: the C{ProcessProtocol} connected to us.
-    @ivar data: a C{str} of data written to us.
+    @ivar data: a L{bytes} of data written to us.
     """
 
 
@@ -263,7 +185,7 @@ class EchoTransport:
         """
         self.proto = processProtocol
         self.closed = False
-        self.data = ''
+        self.data = b''
         processProtocol.makeConnection(self)
 
 
@@ -274,8 +196,8 @@ class EchoTransport:
         """
         self.data += data
         self.proto.outReceived(data)
-        self.proto.outReceived('\r\n')
-        if '\x00' in data: # mimic 'exit' for the shell test
+        self.proto.outReceived(b'\r\n')
+        if b'\x00' in data: # mimic 'exit' for the shell test
             self.loseConnection()
 
 
@@ -299,12 +221,13 @@ class MockProtocol(protocol.Protocol):
     """
     A sample Protocol which stores the data passed to it.
 
-    @ivar packetData: a C{str} of data to be sent when the connection is made.
-    @ivar data: a C{str} of the data passed to us.
+    @ivar packetData: a L{bytes} of data to be sent when the connection is
+        made.
+    @ivar data: a L{bytes} of the data passed to us.
     @ivar open: True if the channel is open.
     @ivar reason: if not None, the reason the protocol was closed.
     """
-    packetData = ''
+    packetData = b''
 
 
     def connectionMade(self):
@@ -313,7 +236,7 @@ class MockProtocol(protocol.Protocol):
         along.
         """
 
-        self.data = ''
+        self.data = b''
         self.open = True
         self.reason = None
         if self.packetData:
@@ -327,8 +250,7 @@ class MockProtocol(protocol.Protocol):
         the data.
         """
         self.data += data
-        if self.transport is not None:
-            self.transport.write(data + '~')
+        self.transport.write(data + b'~')
 
 
     def connectionLost(self, reason):
@@ -345,15 +267,15 @@ class StubConnection(object):
     A stub for twisted.conch.ssh.connection.SSHConnection.  Record the data
     that channels send, and when they try to close the connection.
 
-    @ivar data: a C{dict} mapping C{SSHChannel}s to a C{list} of C{str} of data
-        they sent.
-    @ivar extData: a C{dict} mapping L{SSHChannel}s to a C{list} of C{tuple} of
-        (C{int}, C{str}) of extended data they sent.
-    @ivar requests: a C{dict} mapping L{SSHChannel}s to a C{list} of C{tuple}
-        of (C{str}, C{str}) of channel requests they made.
-    @ivar eofs: a C{dict} mapping L{SSHChannel}s to C{true} if they have sent
+    @ivar data: a L{dict} mapping C{SSHChannel}s to a C{list} of L{bytes} of
+        data they sent.
+    @ivar extData: a L{dict} mapping L{SSHChannel}s to a C{list} of L{tuple} of
+        (L{int}, L{bytes}) of extended data they sent.
+    @ivar requests: a L{dict} mapping L{SSHChannel}s to a C{list} of L{tuple}
+        of (L{str}, L{bytes}) of channel requests they made.
+    @ivar eofs: a L{dict} mapping L{SSHChannel}s to C{true} if they have sent
         an EOF.
-    @ivar closes: a C{dict} mapping L{SSHChannel}s to C{true} if they have sent
+    @ivar closes: a L{dict} mapping L{SSHChannel}s to C{true} if they have sent
         a close.
     """
 
@@ -421,13 +343,13 @@ class StubTransport:
     A stub transport which records the data written.
 
     @ivar buf: the data sent to the transport.
-    @type buf: C{str}
+    @type buf: L{bytes}
 
     @ivar close: flags indicating if the transport has been closed.
-    @type close: C{bool}
+    @type close: L{bool}
     """
 
-    buf = ''
+    buf = b''
     close = False
 
 
@@ -459,15 +381,22 @@ class StubTransport:
         self.close = True
 
 
+    def setTcpNoDelay(self, enabled):
+        """
+        Pretend to set C{TCP_NODELAY}.
+        """
+        # Required for testing SSHSessionForUnixConchUser.
+
+
 class StubTransportWithWriteErr(StubTransport):
     """
     A version of StubTransport which records the error data sent to it.
 
     @ivar err: the extended data sent to the transport.
-    @type err: C{str}
+    @type err: L{bytes}
     """
 
-    err = ''
+    err = b''
 
 
     def writeErr(self, data):
@@ -528,9 +457,9 @@ class SessionInterfaceTests(unittest.TestCase):
         """
         s = session.SSHSession(avatar=object) # use object because it doesn't
                                               # have an adapter
-        self.assertEqual(s.buf, '')
-        self.assertIs(s.client, None)
-        self.assertIs(s.session, None)
+        self.assertEqual(s.buf, b'')
+        self.assertIsNone(s.client)
+        self.assertIsNone(s.session)
 
 
     def test_client_dataReceived(self):
@@ -538,10 +467,10 @@ class SessionInterfaceTests(unittest.TestCase):
         SSHSession.dataReceived() passes data along to a client.  If the data
         comes before there is a client, the data should be discarded.
         """
-        self.session.dataReceived('1')
+        self.session.dataReceived(b'1')
         self.session.client = StubClient()
-        self.session.dataReceived('2')
-        self.assertEqual(self.session.client.transport.buf, '2')
+        self.session.dataReceived(b'2')
+        self.assertEqual(self.session.client.transport.buf, b'2')
 
     def test_client_extReceived(self):
         """
@@ -549,11 +478,11 @@ class SessionInterfaceTests(unittest.TestCase):
         to the client.  If the data comes before there is a client, or if the
         data is not of type EXTENDED_DATA_STDERR, it is discared.
         """
-        self.session.extReceived(connection.EXTENDED_DATA_STDERR, '1')
-        self.session.extReceived(255, '2') # 255 is arbitrary
+        self.session.extReceived(connection.EXTENDED_DATA_STDERR, b'1')
+        self.session.extReceived(255, b'2') # 255 is arbitrary
         self.session.client = StubClient()
-        self.session.extReceived(connection.EXTENDED_DATA_STDERR, '3')
-        self.assertEqual(self.session.client.transport.err, '3')
+        self.session.extReceived(connection.EXTENDED_DATA_STDERR, b'3')
+        self.assertEqual(self.session.client.transport.err, b'3')
 
 
     def test_client_extReceivedWithoutWriteErr(self):
@@ -565,7 +494,7 @@ class SessionInterfaceTests(unittest.TestCase):
         client.transport = StubTransport() # doesn't have writeErr
 
         # should not raise an error
-        self.session.extReceived(connection.EXTENDED_DATA_STDERR, 'ignored')
+        self.session.extReceived(connection.EXTENDED_DATA_STDERR, b'ignored')
 
 
 
@@ -585,9 +514,9 @@ class SessionInterfaceTests(unittest.TestCase):
         When a subsystem request fails, SSHSession.client should not be set.
         """
         ret = self.session.requestReceived(
-            'subsystem', common.NS('BadSubsystem'))
+            b'subsystem', common.NS(b'BadSubsystem'))
         self.assertFalse(ret)
-        self.assertIs(self.session.client, None)
+        self.assertIsNone(self.session.client)
 
 
     def test_lookupSubsystem(self):
@@ -597,7 +526,7 @@ class SessionInterfaceTests(unittest.TestCase):
         the client.
         """
         ret = self.session.requestReceived(
-            'subsystem', common.NS('TestSubsystem') + 'data')
+            b'subsystem', common.NS(b'TestSubsystem') + b'data')
         self.assertTrue(ret)
         self.assertIsInstance(self.session.client, protocol.ProcessProtocol)
         self.assertIs(self.session.client.transport.proto,
@@ -614,10 +543,10 @@ class SessionInterfaceTests(unittest.TestCase):
         s = session.SSHSession(avatar=SubsystemOnlyAvatar(),
                                conn=StubConnection())
         ret = s.request_subsystem(
-            common.NS('subsystem') + 'data')
+            common.NS(b'subsystem') + b'data')
         self.assertTrue(ret)
-        self.assertIsNot(s.client, None)
-        self.assertIs(s.conn.closes.get(s), None)
+        self.assertIsNotNone(s.client)
+        self.assertIsNone(s.conn.closes.get(s))
         s.eofReceived()
         self.assertTrue(s.conn.closes.get(s))
         # these should not raise errors
@@ -638,14 +567,14 @@ class SessionInterfaceTests(unittest.TestCase):
         # subsystems didn't get extended data
         #self.session.extReceived(connection.EXTENDED_DATA_STDERR, '2')
 
-        self.session.requestReceived('subsystem',
-                                     common.NS('TestSubsystem') + 'data')
+        self.session.requestReceived(b'subsystem',
+                                     common.NS(b'TestSubsystem') + b'data')
 
         self.assertEqual(self.session.conn.data[self.session],
-                ['\x00\x00\x00\x0dTestSubsystemdata~'])
-        self.session.dataReceived('more data')
+                [b'\x00\x00\x00\x0dTestSubsystemdata~'])
+        self.session.dataReceived(b'more data')
         self.assertEqual(self.session.conn.data[self.session][-1],
-                'more data~')
+                b'more data~')
 
 
     def test_lookupSubsystem_closeReceived(self):
@@ -653,8 +582,8 @@ class SessionInterfaceTests(unittest.TestCase):
         SSHSession.closeReceived() should sent a close message to the remote
         side.
         """
-        self.session.requestReceived('subsystem',
-                                     common.NS('TestSubsystem') + 'data')
+        self.session.requestReceived(b'subsystem',
+                                     common.NS(b'TestSubsystem') + b'data')
 
         self.session.closeReceived()
         self.assertTrue(self.session.conn.closes[self.session])
@@ -678,14 +607,14 @@ class SessionInterfaceTests(unittest.TestCase):
         calling openShell() with a ProcessProtocol to attach.
         """
         # gets a shell the first time
-        ret = self.session.requestReceived('shell', '')
+        ret = self.session.requestReceived(b'shell', b'')
         self.assertTrue(ret)
         self.assertSessionIsStubSession()
         self.assertIsInstance(self.session.client,
                               session.SSHSessionProcessProtocol)
         self.assertIs(self.session.session.shellProtocol, self.session.client)
         # doesn't get a shell the second time
-        self.assertFalse(self.session.requestReceived('shell', ''))
+        self.assertFalse(self.session.requestReceived(b'shell', b''))
         self.assertRequestRaisedRuntimeError()
 
 
@@ -694,17 +623,17 @@ class SessionInterfaceTests(unittest.TestCase):
         When a client executes a shell, it should be able to give pass data
         back and forth between the local and the remote side.
         """
-        ret = self.session.requestReceived('shell', '')
+        ret = self.session.requestReceived(b'shell', b'')
         self.assertTrue(ret)
         self.assertSessionIsStubSession()
-        self.session.dataReceived('some data\x00')
+        self.session.dataReceived(b'some data\x00')
         self.assertEqual(self.session.session.shellTransport.data,
-                          'some data\x00')
+                          b'some data\x00')
         self.assertEqual(self.session.conn.data[self.session],
-                          ['some data\x00', '\r\n'])
+                          [b'some data\x00', b'\r\n'])
         self.assertTrue(self.session.session.shellTransport.closed)
         self.assertEqual(self.session.conn.requests[self.session],
-                          [('exit-status', '\x00\x00\x00\x00', False)])
+                          [(b'exit-status', b'\x00\x00\x00\x00', False)])
 
 
     def test_requestExec(self):
@@ -714,20 +643,20 @@ class SessionInterfaceTests(unittest.TestCase):
         calling execCommand with a ProcessProtocol to attach and the
         command line.
         """
-        ret = self.session.requestReceived('exec',
-                                           common.NS('failure'))
+        ret = self.session.requestReceived(b'exec',
+                                           common.NS(b'failure'))
         self.assertFalse(ret)
         self.assertRequestRaisedRuntimeError()
-        self.assertIs(self.session.client, None)
+        self.assertIsNone(self.session.client)
 
-        self.assertTrue(self.session.requestReceived('exec',
-                                                     common.NS('success')))
+        self.assertTrue(self.session.requestReceived(b'exec',
+                                                     common.NS(b'success')))
         self.assertSessionIsStubSession()
         self.assertIsInstance(self.session.client,
                               session.SSHSessionProcessProtocol)
         self.assertIs(self.session.session.execProtocol, self.session.client)
         self.assertEqual(self.session.session.execCommandLine,
-                'success')
+                b'success')
 
 
     def test_requestExecWithData(self):
@@ -735,20 +664,20 @@ class SessionInterfaceTests(unittest.TestCase):
         When a client executes a command, it should be able to give pass data
         back and forth.
         """
-        ret = self.session.requestReceived('exec',
-                                           common.NS('repeat hello'))
+        ret = self.session.requestReceived(b'exec',
+                                           common.NS(b'repeat hello'))
         self.assertTrue(ret)
         self.assertSessionIsStubSession()
-        self.session.dataReceived('some data')
-        self.assertEqual(self.session.session.execTransport.data, 'some data')
+        self.session.dataReceived(b'some data')
+        self.assertEqual(self.session.session.execTransport.data, b'some data')
         self.assertEqual(self.session.conn.data[self.session],
-                          ['hello', 'some data', '\r\n'])
+                          [b'hello', b'some data', b'\r\n'])
         self.session.eofReceived()
         self.session.closeReceived()
         self.session.closed()
         self.assertTrue(self.session.session.execTransport.closed)
         self.assertEqual(self.session.conn.requests[self.session],
-                          [('exit-status', '\x00\x00\x00\x00', False)])
+                          [(b'exit-status', b'\x00\x00\x00\x00', False)])
 
 
     def test_requestPty(self):
@@ -760,16 +689,16 @@ class SessionInterfaceTests(unittest.TestCase):
         """
         # 'bad' terminal type fails
         ret = self.session.requestReceived(
-            'pty_req',  session.packRequest_pty_req(
-                'bad', (1, 2, 3, 4), ''))
+            b'pty_req',  session.packRequest_pty_req(
+                b'bad', (1, 2, 3, 4), b''))
         self.assertFalse(ret)
         self.assertSessionIsStubSession()
         self.assertRequestRaisedRuntimeError()
         # 'good' terminal type succeeds
-        self.assertTrue(self.session.requestReceived('pty_req',
-            session.packRequest_pty_req('good', (1, 2, 3, 4), '')))
+        self.assertTrue(self.session.requestReceived(b'pty_req',
+            session.packRequest_pty_req(b'good', (1, 2, 3, 4), b'')))
         self.assertEqual(self.session.session.ptyRequest,
-                ('good', (1, 2, 3, 4), []))
+                (b'good', (1, 2, 3, 4), []))
 
 
     def test_requestWindowChange(self):
@@ -779,12 +708,12 @@ class SessionInterfaceTests(unittest.TestCase):
         avatar, then calling windowChanged with the new window size.
         """
         ret = self.session.requestReceived(
-            'window_change',
+            b'window_change',
             session.packRequest_window_change((0, 0, 0, 0)))
         self.assertFalse(ret)
         self.assertRequestRaisedRuntimeError()
         self.assertSessionIsStubSession()
-        self.assertTrue(self.session.requestReceived('window_change',
+        self.assertTrue(self.session.requestReceived(b'window_change',
             session.packRequest_window_change((1, 2, 3, 4))))
         self.assertEqual(self.session.session.windowChange,
                 (1, 2, 3, 4))
@@ -792,7 +721,7 @@ class SessionInterfaceTests(unittest.TestCase):
 
     def test_eofReceived(self):
         """
-        When an EOF is received and a ISession adapter is present, it should
+        When an EOF is received and an ISession adapter is present, it should
         be notified of the EOF message.
         """
         self.session.session = session.ISession(self.session.avatar)
@@ -805,13 +734,13 @@ class SessionInterfaceTests(unittest.TestCase):
         When a close is received, the session should send a close message.
         """
         ret = self.session.closeReceived()
-        self.assertIs(ret, None)
+        self.assertIsNone(ret)
         self.assertTrue(self.session.conn.closes[self.session])
 
 
     def test_closed(self):
         """
-        When a close is received and a ISession adapter is present, it should
+        When a close is received and an ISession adapter is present, it should
         be notified of the close message.
         """
         self.session.session = session.ISession(self.session.avatar)
@@ -832,7 +761,7 @@ class SessionWithNoAvatarTests(unittest.TestCase):
     def setUp(self):
         self.session = session.SSHSession()
         self.session.avatar = StubAvatar()
-        self.assertIs(self.session.session, None)
+        self.assertIsNone(self.session.session)
 
 
     def assertSessionProvidesISession(self):
@@ -848,7 +777,7 @@ class SessionWithNoAvatarTests(unittest.TestCase):
         If an ISession adapter isn't already present, request_shell should get
         one.
         """
-        self.session.requestReceived('shell', '')
+        self.session.requestReceived(b'shell', b'')
         self.assertSessionProvidesISession()
 
 
@@ -857,8 +786,8 @@ class SessionWithNoAvatarTests(unittest.TestCase):
         If an ISession adapter isn't already present, request_exec should get
         one.
         """
-        self.session.requestReceived('exec',
-                                     common.NS('success'))
+        self.session.requestReceived(b'exec',
+                                     common.NS(b'success'))
         self.assertSessionProvidesISession()
 
 
@@ -867,9 +796,9 @@ class SessionWithNoAvatarTests(unittest.TestCase):
         If an ISession adapter isn't already present, request_pty_req should
         get one.
         """
-        self.session.requestReceived('pty_req',
+        self.session.requestReceived(b'pty_req',
                                      session.packRequest_pty_req(
-                'term', (0, 0, 0, 0), ''))
+                b'term', (0, 0, 0, 0), b''))
         self.assertSessionProvidesISession()
 
 
@@ -879,7 +808,7 @@ class SessionWithNoAvatarTests(unittest.TestCase):
         should get one.
         """
         self.session.requestReceived(
-            'window_change',
+            b'window_change',
             session.packRequest_window_change(
                 (1, 1, 1, 1)))
         self.assertSessionProvidesISession()
@@ -901,12 +830,12 @@ class WrappersTests(unittest.TestCase):
         protocol.transport = StubTransport()
         protocol.connectionMade()
         wrapped = session.wrapProtocol(protocol)
-        wrapped.dataReceived('dataReceived')
-        self.assertEqual(protocol.transport.buf, 'dataReceived')
-        wrapped.write('data')
-        wrapped.writeSequence(['1', '2'])
+        wrapped.dataReceived(b'dataReceived')
+        self.assertEqual(protocol.transport.buf, b'dataReceived')
+        wrapped.write(b'data')
+        wrapped.writeSequence([b'1', b'2'])
         wrapped.loseConnection()
-        self.assertEqual(protocol.data, 'data12')
+        self.assertEqual(protocol.data, b'data12')
         protocol.reason.trap(error.ConnectionDone)
 
     def test_wrapProcessProtocol_Protocol(self):
@@ -920,8 +849,8 @@ class WrappersTests(unittest.TestCase):
         protocol.transport = StubTransport()
         process_protocol = session.wrapProcessProtocol(protocol)
         process_protocol.connectionMade()
-        process_protocol.outReceived('data')
-        self.assertEqual(protocol.transport.buf, 'data~')
+        process_protocol.outReceived(b'data')
+        self.assertEqual(protocol.transport.buf, b'data~')
         process_protocol.processEnded(failure.Failure(
             error.ProcessTerminated(0, None, None)))
         protocol.reason.trap(error.ProcessTerminated)
@@ -948,23 +877,24 @@ class HelpersTests(unittest.TestCase):
             byte    mode number
             uint32  mode value
         """
-        self.assertEqual(session.parseRequest_pty_req(common.NS('xterm') +
+        self.assertEqual(session.parseRequest_pty_req(common.NS(b'xterm') +
                                                        struct.pack('>4L',
                                                                    1, 2, 3, 4)
                                                        + common.NS(
                     struct.pack('>BL', 5, 6))),
-                          ('xterm', (2, 1, 3, 4), [(5, 6)]))
+                          (b'xterm', (2, 1, 3, 4), [(5, 6)]))
 
 
     def test_packRequest_pty_req_old(self):
         """
         See test_parseRequest_pty_req for the payload format.
         """
-        packed = session.packRequest_pty_req('xterm', (2, 1, 3, 4),
-                                             '\x05\x00\x00\x00\x06')
+        packed = session.packRequest_pty_req(b'xterm', (2, 1, 3, 4),
+                                             b'\x05\x00\x00\x00\x06')
 
         self.assertEqual(packed,
-                          common.NS('xterm') + struct.pack('>4L', 1, 2, 3, 4) +
+                          common.NS(b'xterm') +
+                          struct.pack('>4L', 1, 2, 3, 4) +
                           common.NS(struct.pack('>BL', 5, 6)))
 
 
@@ -972,10 +902,11 @@ class HelpersTests(unittest.TestCase):
         """
         See test_parseRequest_pty_req for the payload format.
         """
-        packed = session.packRequest_pty_req('xterm', (2, 1, 3, 4),
-                                             '\x05\x00\x00\x00\x06')
+        packed = session.packRequest_pty_req(b'xterm', (2, 1, 3, 4),
+                                             b'\x05\x00\x00\x00\x06')
         self.assertEqual(packed,
-                          common.NS('xterm') + struct.pack('>4L', 1, 2, 3, 4) +
+                          common.NS(b'xterm') +
+                          struct.pack('>4L', 1, 2, 3, 4) +
                           common.NS(struct.pack('>BL', 5, 6)))
 
 
@@ -1064,9 +995,9 @@ class SSHSessionProcessProtocolTests(unittest.TestCase):
         SSHSessionProcessProtocol.connectionMade() should check if there's a
         'buf' attribute on its session and write it to the transport if so.
         """
-        self.session.buf = 'buffer'
+        self.session.buf = b'buffer'
         self.pp.connectionMade()
-        self.assertEqual(self.transport.buf, 'buffer')
+        self.assertEqual(self.transport.buf, b'buffer')
 
 
     def test_getSignalName(self):
@@ -1105,9 +1036,9 @@ class SSHSessionProcessProtocolTests(unittest.TestCase):
         When data is passed to the outReceived method, it should be sent to
         the session's write method.
         """
-        self.pp.outReceived('test data')
+        self.pp.outReceived(b'test data')
         self.assertEqual(self.session.conn.data[self.session],
-                ['test data'])
+                [b'test data'])
 
 
     def test_write(self):
@@ -1115,18 +1046,18 @@ class SSHSessionProcessProtocolTests(unittest.TestCase):
         When data is passed to the write method, it should be sent to the
         session channel's write method.
         """
-        self.pp.write('test data')
+        self.pp.write(b'test data')
         self.assertEqual(self.session.conn.data[self.session],
-                ['test data'])
+                [b'test data'])
 
     def test_writeSequence(self):
         """
         When a sequence is passed to the writeSequence method, it should be
         joined together and sent to the session channel's write method.
         """
-        self.pp.writeSequence(['test ', 'data'])
+        self.pp.writeSequence([b'test ', b'data'])
         self.assertEqual(self.session.conn.data[self.session],
-                ['test data'])
+                [b'test data'])
 
 
     def test_errReceived(self):
@@ -1134,9 +1065,9 @@ class SSHSessionProcessProtocolTests(unittest.TestCase):
         When data is passed to the errReceived method, it should be sent to
         the session's writeExtended method.
         """
-        self.pp.errReceived('test data')
+        self.pp.errReceived(b'test data')
         self.assertEqual(self.session.conn.extData[self.session],
-                [(1, 'test data')])
+                [(1, b'test data')])
 
 
     def test_outConnectionLost(self):
@@ -1187,7 +1118,7 @@ class SSHSessionProcessProtocolTests(unittest.TestCase):
         """
         self.pp.processEnded(Failure(ProcessDone(None)))
         self.assertRequestsEqual(
-            [('exit-status', struct.pack('>I', 0) , False)])
+            [(b'exit-status', struct.pack('>I', 0) , False)])
         self.assertSessionClosed()
 
 
@@ -1201,11 +1132,11 @@ class SSHSessionProcessProtocolTests(unittest.TestCase):
             Failure(ProcessTerminated(1,
                 signal.SIGTERM, 1 << 7))) # 7th bit means core dumped
         self.assertRequestsEqual(
-            [('exit-signal',
-              common.NS('TERM') # signal name
-              + '\x01' # core dumped is true
-              + common.NS('') # error message
-              + common.NS(''), # language tag
+            [(b'exit-signal',
+              common.NS(b'TERM') # signal name
+              + b'\x01' # core dumped is true
+              + common.NS(b'') # error message
+              + common.NS(b''), # language tag
               False)])
         self.assertSessionClosed()
 
@@ -1221,8 +1152,8 @@ class SSHSessionProcessProtocolTests(unittest.TestCase):
         # see comments in test_processEndedWithExitSignalCoreDump for the
         # meaning of the parts in the request
         self.assertRequestsEqual(
-             [('exit-signal', common.NS('TERM') + '\x00' + common.NS('') +
-               common.NS(''), False)])
+             [(b'exit-signal', common.NS(b'TERM') + b'\x00' + common.NS(b'') +
+               common.NS(b''), False)])
         self.assertSessionClosed()
 
 
@@ -1246,5 +1177,5 @@ class SSHSessionClientTests(unittest.TestCase):
         """
         client = session.SSHSessionClient()
         client.transport = StubTransport()
-        client.dataReceived('test data')
-        self.assertEqual(client.transport.buf, 'test data')
+        client.dataReceived(b'test data')
+        self.assertEqual(client.transport.buf, b'test data')
